HealthCheckService

Struct HealthCheckService 

pub struct HealthCheckService { /* private fields */ }
Implements a client for the Vision AI API.

Example

async fn sample(
) -> anyhow::Result<()> {
    let client = HealthCheckService::builder().build().await?;
    let response = client.health_check()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}

Service Description

HealthCheckService provides an interface for Vertex AI Vision Cluster Health Check.

Configuration

To configure HealthCheckService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

HealthCheckService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap HealthCheckService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl HealthCheckService

pub fn builder() -> ClientBuilder

Returns a builder for HealthCheckService.

let client = HealthCheckService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: HealthCheckService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn health_check(&self) -> HealthCheck

HealthCheck method checks the health status of the cluster.

Example
use google_cloud_visionai_v1::Result;
async fn sample(
   client: &HealthCheckService
) -> Result<()> {
    let response = client.health_check()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_visionai_v1::Result;
async fn sample(
   client: &HealthCheckService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_visionai_v1::Result;
async fn sample(
   client: &HealthCheckService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_visionai_v1::Result;
async fn sample(
   client: &HealthCheckService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_visionai_v1::Result;
async fn sample(
   client: &HealthCheckService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_visionai_v1::Result;
async fn sample(
   client: &HealthCheckService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_visionai_v1::Result;
async fn sample(
   client: &HealthCheckService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}