pub struct HealthCheckService { /* private fields */ }Expand description
Implements a client for the Vision AI API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = HealthCheckService::builder().build().await?;
let response = client.health_check()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
HealthCheckService provides an interface for Vertex AI Vision Cluster Health Check.
Configuration
To configure HealthCheckService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://visionai.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
HealthCheckService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap HealthCheckService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl HealthCheckService
impl HealthCheckService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for HealthCheckService.
let client = HealthCheckService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: HealthCheckService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: HealthCheckService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn health_check(&self) -> HealthCheck
pub fn health_check(&self) -> HealthCheck
HealthCheck method checks the health status of the cluster.
Example
use google_cloud_visionai_v1::Result;
async fn sample(
client: &HealthCheckService
) -> Result<()> {
let response = client.health_check()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_visionai_v1::Result;
async fn sample(
client: &HealthCheckService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_visionai_v1::Result;
async fn sample(
client: &HealthCheckService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_visionai_v1::Result;
async fn sample(
client: &HealthCheckService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_visionai_v1::Result;
async fn sample(
client: &HealthCheckService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_visionai_v1::Result;
async fn sample(
client: &HealthCheckService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_visionai_v1::Result;
async fn sample(
client: &HealthCheckService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for HealthCheckService
impl Clone for HealthCheckService
Sourcefn clone(&self) -> HealthCheckService
fn clone(&self) -> HealthCheckService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for HealthCheckService
impl !UnwindSafe for HealthCheckService
impl Freeze for HealthCheckService
impl Send for HealthCheckService
impl Sync for HealthCheckService
impl Unpin for HealthCheckService
impl UnsafeUnpin for HealthCheckService